@@ -3,6 +3,6 @@
 __author__ = 'Michael Joseph'
 __email__ = 'michaeljoseph@gmail.com'
 __url__ = 'https://github.com/michaeljoseph/snide'
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
-from .models import Deck, Slide
\ No newline at end of file
+from .models import Deck, Slide  # noqa
